@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2010 The VP8 project authors. All Rights Reserved.
+ *  Copyright (c) 2010 The WebM project authors. All Rights Reserved.
  *
  *  Use of this source code is governed by a BSD-style license
  *  that can be found in the LICENSE file in the root of the source
@@ -17,12 +17,11 @@
 #ifndef SCALE_MODE_H
 #define SCALE_MODE_H
 
-typedef enum
-{
-    MAINTAIN_ASPECT_RATIO   = 0x0,
-    SCALE_TO_FIT            = 0x1,
-    CENTER                  = 0x2,
-    OTHER                   = 0x3
+typedef enum {
+  MAINTAIN_ASPECT_RATIO   = 0x0,
+  SCALE_TO_FIT            = 0x1,
+  CENTER                  = 0x2,
+  OTHER                   = 0x3
 } SCALE_MODE;
 
 
