@@ -52,7 +52,7 @@ static const char *exec_name;
 static const struct
 {
     char const *name;
-    const vpx_codec_iface_t *iface;
+    vpx_codec_iface_t *iface;
     unsigned int             fourcc;
     unsigned int             fourcc_mask;
 } ifaces[] =
@@ -152,7 +152,8 @@ static void usage_exit()
             "write to. If the\n  argument does not include any escape "
             "characters, the output will be\n  written to a single file. "
             "Otherwise, the filename will be calculated by\n  expanding "
-            "the following escape characters:\n"
+            "the following escape characters:\n");
+    fprintf(stderr,
             "\n\t%%w   - Frame width"
             "\n\t%%h   - Frame height"
             "\n\t%%<n> - Frame number, zero padded to <n> places (1..9)"
@@ -356,7 +357,7 @@ void out_put(void *out, const uint8_t *buf, unsigned int len, int do_md5)
     }
     else
     {
-        if(fwrite(buf, 1, len, out));
+        (void) fwrite(buf, 1, len, out);
     }
 }
 
@@ -502,7 +503,7 @@ nestegg_seek_cb(int64_t offset, int whence, void * userdata)
         case NESTEGG_SEEK_CUR: whence = SEEK_CUR; break;
         case NESTEGG_SEEK_END: whence = SEEK_END; break;
     };
-    return fseek(userdata, offset, whence)? -1 : 0;
+    return fseek(userdata, (long)offset, whence)? -1 : 0;
 }
 
 
@@ -559,7 +560,7 @@ webm_guess_framerate(struct input_ctx *input,
         goto fail;
 
     *fps_num = (i - 1) * 1000000;
-    *fps_den = tstamp / 1000;
+    *fps_den = (unsigned int)(tstamp / 1000);
     return 0;
 fail:
     nestegg_destroy(input->nestegg_ctx);
@@ -580,10 +581,10 @@ file_is_webm(struct input_ctx *input,
     unsigned int i, n;
     int          track_type = -1;
 
-    nestegg_io io = {nestegg_read_cb, nestegg_seek_cb, nestegg_tell_cb,
-                     input->infile};
+    nestegg_io io = {nestegg_read_cb, nestegg_seek_cb, nestegg_tell_cb, 0};
     nestegg_video_params params;
 
+    io.userdata = input->infile;
     if(nestegg_init(&input->nestegg_ctx, io, NULL))
         goto fail;
 
@@ -647,7 +648,7 @@ void generate_filename(const char *pattern, char *out, size_t q_len,
         {
             size_t pat_len;
 
-            // parse the pattern
+            /* parse the pattern */
             q[q_len - 1] = '\0';
             switch(p[1])
             {
@@ -677,7 +678,7 @@ void generate_filename(const char *pattern, char *out, size_t q_len,
         {
             size_t copy_len;
 
-            // copy the next segment
+            /* copy the next segment */
             if(!next_pat)
                 copy_len = strlen(p);
             else
@@ -922,7 +923,7 @@ int main(int argc, const char **argv_)
             p = strchr(p, '%');
             if(p && p[1] >= '1' && p[1] <= '9')
             {
-                // pattern contains sequence number, so it's not unique.
+                /* pattern contains sequence number, so it's not unique. */
                 single_file = 0;
                 break;
             }
@@ -962,7 +963,8 @@ int main(int argc, const char **argv_)
           That will have to wait until these tools support WebM natively.*/
         sprintf(buffer, "YUV4MPEG2 C%s W%u H%u F%u:%u I%c\n",
                 "420jpeg", width, height, fps_num, fps_den, 'p');
-        out_put(out, (unsigned char *)buffer, strlen(buffer), do_md5);
+        out_put(out, (unsigned char *)buffer,
+                (unsigned int)strlen(buffer), do_md5);
     }
 
     /* Try to determine the codec from the fourcc. */
@@ -1040,7 +1042,7 @@ int main(int argc, const char **argv_)
 
         vpx_usec_timer_start(&timer);
 
-        if (vpx_codec_decode(&decoder, buf, buf_sz, NULL, 0))
+        if (vpx_codec_decode(&decoder, buf, (unsigned int)buf_sz, NULL, 0))
         {
             const char *detail = vpx_codec_error_detail(&decoder);
             fprintf(stderr, "Failed to decode frame: %s\n", vpx_codec_error(&decoder));
@@ -1052,7 +1054,7 @@ int main(int argc, const char **argv_)
         }
 
         vpx_usec_timer_mark(&timer);
-        dx_time += vpx_usec_timer_elapsed(&timer);
+        dx_time += (unsigned int)vpx_usec_timer_elapsed(&timer);
 
         ++frame_in;
 
@@ -1064,9 +1066,14 @@ int main(int argc, const char **argv_)
         }
         frames_corrupted += corrupted;
 
+        vpx_usec_timer_start(&timer);
+
         if ((img = vpx_codec_get_frame(&decoder, &iter)))
             ++frame_out;
 
+        vpx_usec_timer_mark(&timer);
+        dx_time += (unsigned int)vpx_usec_timer_elapsed(&timer);
+
         if (progress)
             show_progress(frame_in, frame_out, dx_time);
 
